![Cartopy logo](http://scitools.org.uk/cartopy/docs/latest/_static/cartopy.png)

Cartopy
-------
[![Build Status](https://api.travis-ci.org/repositories/SciTools/cartopy.svg?branch=master)](https://travis-ci.org/SciTools/cartopy/branches)

Cartopy is a Python package designed to make drawing maps for data analysis and visualisation easy.

It features:

 * object oriented projection definitions
 * point, line, polygon and image transformations between projections
 * integration to expose advanced mapping in Matplotlib with a simple and intuitive interface
 * powerful vector data handling by integrating shapefile reading with Shapely capabilities 

Licence
-------
Cartopy is licenced under GNU Lesser General Public License (LGPLv3).
